==> vokoscreen_2.0.16~beta.orig.tar.gz: vokoscreen-2.0.16-beta/main.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>QvkMail</name>
    <message>
        <source>Mail last Video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You find the Video as attachment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QvkWebcamBusyDialog</name>
    <message>
        <source>Webcam is busy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Noborder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Border</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Codec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Player</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Device %1 is busy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Go</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mailinglist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Support</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Developer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Frames</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Beta openSUSE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Beta Ubuntu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Donate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Program for recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Translations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New version available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> vokoscreen_2.1.8~beta.orig.tar.gz: vokoscreen-2.1.8-beta/main.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NoPlayerDialog</name>
    <message>
        <source>Please install a videoplayer</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right click for menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User-defined</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Codec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Player</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Go</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Support</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Developer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Frames</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Donate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Program for recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Translations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New version available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Displays</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Developer Homepage</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
